import React, { useEffect, useRef, useState } from "react";
import Chart from "chart.js/auto";

interface ChartData {
  labels: string[];
  datasets: {
    data: number[];
    label: string;
    borderColor: string;
    backgroundColor: string;
    fill: boolean;
  }[];
}

const LineChart: React.FC = () => {
  const [chartData, setChartData] = useState<ChartData | null>(null);
  const chartRef = useRef<Chart | null>(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        
        const response = await fetch("http://localhost:3000/api/data");
        const data = await response.json();
        setChartData(data);
      } catch (error) {
        console.error("Error fetching chart data:", error);
      }
    };

    fetchData();

    // Cleanup function to ensure any existing chart is destroyed when component unmounts
    return () => {
      if (chartRef.current) {
        chartRef.current.destroy();
      }
    };
  }, []);

  useEffect(() => {
    if (!chartData) return;

    const canvas = document.getElementById("myChart") as HTMLCanvasElement | null;
    if (canvas) {
      const ctx = canvas.getContext("2d");
      if (ctx) {
        if (chartRef.current) {
          chartRef.current.destroy();
        }
        chartRef.current = new Chart(ctx, {
          type: "line",
          data: chartData,
        });
      }
    }

    // Cleanup function to ensure any existing chart is destroyed when component unmounts
    return () => {
      if (chartRef.current) {
        chartRef.current.destroy();
      }
    };
  }, [chartData]);

  return (
    <div>
      {/* <h1 className="w-[110px] mx-auto mt-10 text-xl font-semibold capitalize">
        Line Chart
      </h1> */}
      {/* <div className="w-[5500px] h-screen flex mx-auto my-auto">
        <div className="border border-gray-400 pt-0 rounded-xl w-full h-fit my-auto shadow-xl"> */}
          <canvas id="myChart"></canvas>
        {/* </div>
      </div> */}
    </div>
  );
};

export default LineChart;
